@@ -46,7 +46,7 @@ lbt05_main <- function(adam_db,
   )
 
   un_mapped <- adam_db$adlb %>%
-    dplyr::select(.data$PARAM, .data$PARAMCD) %>%
+    dplyr::select("PARAM", "PARAMCD") %>%
     distinct() %>%
     tidyr::drop_na() %>%
     dplyr::anti_join(matching, by = c("PARAM", "PARAMCD"))
@@ -59,11 +59,11 @@ lbt05_main <- function(adam_db,
 
   # Add both directions by default.
   map_paramcd <- matching %>%
-    left_join(tidyr::nest(map, ABN_DIR = .data$ABN_DIR), by = "PARAMCD") %>%
+    left_join(tidyr::nest(map, ABN_DIR = "ABN_DIR"), by = "PARAMCD") %>%
     rowwise() %>%
     mutate(ABN_DIR = ifelse((is.null(.data$ABN_DIR)), list(c("Low", "High")), .data$ABN_DIR)) %>%
-    tidyr::unnest(.data$ABN_DIR) %>%
-    dplyr::select(.data$PARAM, .data$ABN_DIR) %>%
+    tidyr::unnest("ABN_DIR") %>%
+    dplyr::select("PARAM", "ABN_DIR") %>%
     mutate(across(everything(), as.character))
 
 
