@@ -152,5 +152,6 @@ lbt14_post <- function(tlg, prune_0 = TRUE, ...) {
 lbt14 <- chevron_t(
   main = lbt14_main,
   preprocess = lbt14_pre,
-  postprocess = lbt14_post
+  postprocess = lbt14_post,
+  dataset = c("adsl", "adlb")
 )
